# CSV-JSON Converter

CSV to JSON converter.

## Introduction

Trabalho desenvolvido para a disciplina Python para Ciência de Dados do curso de pós-graduação em Ciência de Dados e Big Data da PUC Minas - 2021.

### What this project can do

Read a **csv/json** file or a **folder** with csv/json's and convert them to **json/csv**.
This project is a program running on terminal, preferably install with pipx:

```bash
pipx install csv_json_converter_mtba
```

To use, just type in:

```bash
csv_json_converter --help
```

This will list all available options.